@@ -1,10 +1,8 @@
 /**
- *  Copyright (c) 2015, Facebook, Inc.
- *  All rights reserved.
+ * Copyright (c) 2015-present, Facebook, Inc.
  *
- *  This source code is licensed under the BSD-style license found in the
- *  LICENSE file in the root directory of this source tree. An additional grant
- *  of patent rights can be found in the PATENTS file in the same directory.
+ * This source code is licensed under the MIT license found in the
+ * LICENSE file in the root directory of this source tree.
  */
 
 #pragma once
@@ -30,7 +28,7 @@ public:
   const yy::location &getLocation() const
   { return location_; }
 
-  virtual void accept(visitor::AstVisitor *visitor) = 0;
+  virtual void accept(visitor::AstVisitor *visitor) const = 0;
 };
 
 }
